@@ -4,7 +4,7 @@ This source file is part of OGRE
     (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2011 Torus Knot Software Ltd
+Copyright (c) 2000-2012 Torus Knot Software Ltd
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -107,6 +107,31 @@ namespace Ogre {
         virtual unsigned int getHeight(void) const;
         virtual unsigned int getColourDepth(void) const;
 
+		/**
+		 * Sets the pool ID this RenderTarget should query from. Default value is POOL_DEFAULT.
+		 * Set to POOL_NO_DEPTH to avoid using a DepthBuffer (or manually controlling it) @see DepthBuffer
+		 *	@remarks
+		 *		Changing the pool Id will cause the current depth buffer to be detached unless the old
+		 *		id and the new one are the same
+		 */
+		void setDepthBufferPool( uint16 poolId );
+
+		//Returns the pool ID this RenderTarget should query from. @see DepthBuffer
+		uint16 getDepthBufferPool() const;
+
+		DepthBuffer* getDepthBuffer() const;
+
+		//Returns false if couldn't attach
+		virtual bool attachDepthBuffer( DepthBuffer *depthBuffer );
+
+		virtual void detachDepthBuffer();
+
+		/** Detaches DepthBuffer without notifying it from the detach.
+			Useful when called from the DepthBuffer while it iterates through attached
+			RenderTargets (@see DepthBuffer::_setPoolId())
+		*/
+		virtual void _detachDepthBuffer();
+
         /** Tells the target to update it's contents.
             @remarks
                 If OGRE is not running in an automatic rendering loop
@@ -185,6 +210,14 @@ namespace Ogre {
         /** Retrieves a pointer to the viewport with the given index. */
         virtual Viewport* getViewport(unsigned short index);
 
+		/** Retrieves a pointer to the viewport with the given zorder. 
+			@remarks throws if not found.
+		*/
+        virtual Viewport* getViewportByZOrder(int ZOrder);
+
+		/** Returns true if and only if a viewport exists at the given ZOrder. */
+		virtual bool hasViewportWithZOrder(int ZOrder);
+
         /** Removes a viewport at a given ZOrder.
         */
         virtual void removeViewport(int ZOrder);
@@ -321,7 +354,7 @@ namespace Ogre {
         void writeContentsToFile(const String& filename);
 
 		/** Writes the current contents of the render target to the (PREFIX)(time-stamp)(SUFFIX) file.
-			@returns the name of the file used.*/
+			@return the name of the file used.*/
 		virtual String writeContentsToTimestampedFile(const String& filenamePrefix, const String& filenameSuffix);
 
 		virtual bool requiresTextureFlipping() const = 0;
@@ -448,7 +481,8 @@ namespace Ogre {
         unsigned int mWidth;
         unsigned int mHeight;
         unsigned int mColourDepth;
-        bool mIsDepthBuffered;
+		uint16		 mDepthBufferPoolId;
+        DepthBuffer	*mDepthBuffer;
 
         // Stats
 		FrameStats mStats;
